hoppet development team
===========================

Developers past/present
-----------------

* Frederic Dreyer
* [Alexander Karlberg     ](mailto:alexander.karlberg@cern.ch        "email")
* [Paolo Nason            ](mailto:paolo.nason@mib.infn.it           "email")
* [Juan Rojo              ](https://research.vu.nl/en/persons/juan-rojo "homepage")
* [Gavin Salam            ](https://www.physics.ox.ac.uk/our-people/salam "homepage")
* [Giulia Zanderighi      ](https://www.mpp.mpg.de/en/about-us/organization/directors/prof-dr-giulia-zanderighi "homepage")

Additionally, [Andrii Verbytskyi](mailto:andrii.verbytskyi@mpp.mpg.de        "email") contributed significant parts of the CMake infrastructure.

See also the LICENSE file for information on third-party code that has been included.